{% extends "group_user_base.html" %}

<!DOCTYPE html>
<html>
    <head>
		{% block head_group %}
		{{ block.super }}
		{% endblock %}
	</head>

	<body>


    <article>
		{% block group_user %}
		{{block.super}}
		<div id="GroupMngt" class="grid_16">{% csrf_token %}</div>
		{% endblock %}
		{% block user_group %}
		{{block.super}}
		<div id="UserMngt" class="grid_16">{% csrf_token %}</div>
		{% endblock %}
	</article>

	</body>
</html>