/* jTable light color theme - Gray
 * Created by Halil İbrahim Kalkan
 * http://www.jtable.org
 */

@import "../jtable_lightcolor_base.less";

@theme-folder: 'gray';

.jtable_lightcolor_base(@theme-folder);

div.jtable-main-container
{
    div.jtable-title
    {
        .vertical-gradient(#e8e8e8,#bababa);
        border-color: #949494;

        div.jtable-title-text
        {
            .text-shadow(0 1px 0 #fff);
            color: #000;
        }
		
		div.jtable-toolbar
		{
			span.jtable-toolbar-item
			{
				color: black;

				&.jtable-toolbar-item-hover
				{
					background-color: #a8a8a8;
				}
			}
		}
    }

    table.jtable
    {
        tbody
        {
            > tr
            {
				@highlight-color:#8e8e8e;

                &.jtable-row-selected,
                &.jtable-row-selected:hover
                {
                    background-color: @highlight-color;
                }

                &.jtable-row-created,
                &.jtable-row-updated,
                &.jtable-row-deleting
                {
                    background-color: @highlight-color;
                }
            }
        }
    }

    div.jtable-bottom-panel
    {
        .jtable-page-list
        {
            .jtable-page-number-active,.jtable-page-number-active:hover
            {
				@bgcolor: #8e8e8e;

                background-color: @bgcolor;
                border-color: @bgcolor - #222;
            }
        }

        span.jtable-add-record
        {
            a
            {
                color: #5f5f5f;
            }
        }
    }
}

div.jtable-busy-message
{
    border-color: #5f5f5f;
    background-color: #8e8e8e;
}